Price Index
===========

.. currentmodule:: hpipy.price_index

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   RepeatTransactionIndex
   HedonicIndex

.. currentmodule:: hpipy.extensions

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   RandomForestIndex
   NeuralNetworkIndex
